matminer.data_retrieval.tests package — matminer 0.7.0 documentation

# matminer.data_retrieval.tests package

## Submodules

## matminer.data_retrieval.tests.base module

## matminer.data_retrieval.tests.test_retrieve_AFLOW module

## matminer.data_retrieval.tests.test_retrieve_Citrine module

## matminer.data_retrieval.tests.test_retrieve_MDF module

## matminer.data_retrieval.tests.test_retrieve_MP module

class `matminer.data_retrieval.tests.test_retrieve_MP.` `MPDataRetrievalTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_get_data`()

## matminer.data_retrieval.tests.test_retrieve_MPDS module

## matminer.data_retrieval.tests.test_retrieve_MongoDB module

class `matminer.data_retrieval.tests.test_retrieve_MongoDB.` `MongoDataRetrievalTest`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `test_cleaned_projection`()
  `test_remove_ints`()

## Module contents